==> haskell-abstract-par-0.3.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 abstract-par
version:              0.3.3
visibility:           public
id:                   abstract-par-0.3.3-JGpg8odfEz949f1LvZszw6
key:                  abstract-par-0.3.3-JGpg8odfEz949f1LvZszw6
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2011-2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:
    Type classes generalizing the functionality of the '\''monad-par'\'' library.

description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.

    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.

category:             Control,Parallelism,Monads
abi:                  3598e74cd88e0ead9f8c1ebdbfc4991f
exposed:              True
exposed-modules:      Control.Monad.Par.Class Control.Monad.Par.Unsafe
import-dirs:          /usr/lib/ghc-9.0.1/site-local/abstract-par-0.3.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/abstract-par-0.3.3
hs-libraries:         HSabstract-par-0.3.3-JGpg8odfEz949f1LvZszw6
depends:              base-4.15.0.0 deepseq-1.4.5.0
haddock-interfaces:
    /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock

haddock-html:         /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-par-0.3.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 abstract-par
version:              0.3.3
visibility:           public
id:                   abstract-par-0.3.3-EfoGrzx9JcdJf5mY5rKdWk
key:                  abstract-par-0.3.3-EfoGrzx9JcdJf5mY5rKdWk
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2011-2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:
    Type classes generalizing the functionality of the '\''monad-par'\'' library.

description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.

    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.

category:             Control,Parallelism,Monads
abi:                  031ed43fc0c7c56e90d658c77cc907fa
exposed:              True
exposed-modules:      Control.Monad.Par.Class Control.Monad.Par.Unsafe
import-dirs:          /usr/lib/ghc-9.0.2/site-local/abstract-par-0.3.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/abstract-par-0.3.3
hs-libraries:         HSabstract-par-0.3.3-EfoGrzx9JcdJf5mY5rKdWk
depends:              base-4.15.1.0 deepseq-1.4.5.0
haddock-interfaces:
    /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock

haddock-html:         /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
